@@ -3,8 +3,9 @@ package Devel::Chitin::Actionable;
 use strict;
 use warnings;
 
+use Devel::Chitin qw( $VERSION );
+
 use Digest::MD5 qw(md5);
-use List::Util;
 use Carp;
 
 sub new {
